@@ -4,6 +4,25 @@ server <- function(input, output, session) {
   #   tags$style(HTML(paste0(".main-sidebar{width: ", input$sidebarwidth,"%;}")))
   # })
   
+  # ho trec pq s'ha excedit el nombre de files de google sheet
+  # # register entrance and exit time entries
+  # if (dir.exists(".secrets")){
+  #   observe({
+  #     # port <- session$clientData$url_port
+  #     # if (port==""){
+  #       nomapp <- "compareGroups" # canviar a compareGroups/compareGroups_datarus segons si es fa el deploy a isubirana o regicor respectivament 
+  #     # } else {
+  #     #   nomapp <- "compareGroups_cGroupsWUI"
+  #     # }  
+  #     dd <- data.frame(id=session$token, start=as.character(Sys.time()),end=NA,app=nomapp)
+  #     googlesheets4::sheet_append(sheet_id, dd)
+  #     onStop(function(){
+  #       dd <- data.frame(id=session$token, start=NA,end=as.character(Sys.time()),app=nomapp)
+  #       googlesheets4::sheet_append(sheet_id, dd)
+  #     })
+  #   })
+  # }
+
   output$xxx <- renderPrint({
     # cat("summary(rv$dataset)\n")
     # print(summary(rv$dataset))
@@ -14,7 +33,8 @@ server <- function(input, output, session) {
     # cat("summary(rv$datasetorigfiltered)\n")
     # print(summary(rv$datasetorigfiltered)) 
     # print(input$sepSNPs)
-    input$rightPanel
+    # input$rightPanel
+    session$clientData$url_port
   })
   
   output$github <- renderUser({
@@ -731,6 +751,7 @@ server <- function(input, output, session) {
           return(invisible(NULL))
         }
         # fix data
+        dataset <- as_factor(dataset)
         dataset <- as.data.frame(dataset)
         # vl<-attr(dataset,"variable.labels")
         for (i in 1:ncol(dataset)){
@@ -1177,6 +1198,7 @@ server <- function(input, output, session) {
     dd <- rv$datasetorig
     if (NROW(dd)==0) return(invisible(NULL))
     validate(need(dd, "Data not loaded"))
+    
     withProgress(message="Displaying data table", min=0, max=1, {
       which.Surv <- sapply(dd, is.Surv)
       if (any(which.Surv)){
@@ -1200,6 +1222,9 @@ server <- function(input, output, session) {
         if (!identical(ll,names(dd))) nn <- paste0(nn,"<format style='color:grey;font-size:75%'><br><i>",ll,"</i></format>")
       }
   
+      print("xxx")
+      print(head(dd))
+      
       ans <- DT::datatable(dd,
                       escape=FALSE,
                       filter = "top",
@@ -1799,14 +1824,14 @@ server <- function(input, output, session) {
       validate(need(dd, "Data not loaded yet"))
       validate(need(input$plotselevars, "Select one variable"))
       perc<-if (is.null(input$perc)) FALSE else input$perc
-      if (!inherits(dd[,input$plotselevars],"factor"))
+      if (!inherits(dd[,input$plotselevars],"factor") | input$plotresptype=='Survival')
         hide("perc") 
       else 
         show("perc")
       if (!inherits(dd[,input$plotselevars],"Surv"))
-        updateRadioGroupButtons(session, "plotresptype", choices=c("None","Group","Survival")) 
+        updateRadioGroupButtons(session, "plotresptype", choices=c("None","Group","Survival"),selected=input$plotresptype) #@@
       else 
-        updateRadioGroupButtons(session, "plotresptype", choices=c("None","Group"))      
+        updateRadioGroupButtons(session, "plotresptype", choices=c("None","Group"),selected=input$plotresptype) #@@      
       withProgress(message = 'Making plot', value = 0, {
         if (is.null(input$plotresptype) || input$plotresptype=='None')
           form <- paste0("~",input$plotselevars)
